#include "marketplace.h"
#include "database.h"

#include <algorithm>

Marketplace::Marketplace()
{
    auto seller = std::make_unique<Seller>("Max", "Mustermann");
    seller->createUuid();
    sellers_.push_back(std::move(seller));
}

void Marketplace::storeToDb()
{
    Database db;
    db.storeSellers(sellers_);
}

void Marketplace::loadFromDb()
{
    Database db;
    db.loadSellers(sellers_);
}

std::vector<std::unique_ptr<Seller>>& Marketplace::getSellers() { return sellers_; }

int Marketplace::getNextSellerNo()
{
    auto iter = std::max_element(
        sellers_.begin(), sellers_.end(),
        [](const std::unique_ptr<Seller>& a, const std::unique_ptr<Seller>& b) -> bool {
            return a->getSellerNo() < b->getSellerNo();
        });
    return (*iter)->getSellerNo() + 1;
}