#include "sellerdialog.h"

#include "mainwindow.h"

#include <QItemSelectionModel>
#include <QMessageBox>

SellerDialog::SellerDialog(QWidget* parent, Qt::WindowFlags f) : QDialog(parent, f)
{
    ui_.setupUi(this);
    SellerModel* model =
        new SellerModel(dynamic_cast<MainWindow*>(parent)->getMarketplace(), ui_.tableView);
    ui_.tableView->setModel(model);
    ui_.tableView->setColumnHidden(0, true); // hide the uuid
    connect(ui_.newButton, &QPushButton::clicked, this, &SellerDialog::on_newButton_clicked);
}

void SellerDialog::on_newButton_clicked()
{
    ui_.tableView->reset();
    ui_.tableView->model()->insertRows(ui_.tableView->model()->rowCount(), 1);
    ui_.tableView->scrollToBottom();
    ui_.tableView->selectRow(ui_.tableView->model()->rowCount() - 1);
    QModelIndex idx = ui_.tableView->model()->index(ui_.tableView->model()->rowCount() - 1, 2);
    ui_.tableView->setCurrentIndex(idx);
    ui_.tableView->edit(idx);
}

void SellerDialog::accept()
{
    Marketplace* market = dynamic_cast<MainWindow*>(parentWidget())->getMarketplace();
    for (const auto& seller : market->getSellers()) {
        if (seller->getFirstName().empty() || seller->getLastName().empty()) {
            QMessageBox(QMessageBox::Icon::Critical, "Fehler",
                        "Bitte geben Sie bei jedem Verkäufer Vorname und Nachname an.",
                        QMessageBox::StandardButton::Ok, this)
                .exec();
            return;
        }
    }
    QDialog::accept();
}